@@ -7,7 +7,7 @@
 /*  commands.                                                  */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-1998 by David F. Skoll                  */
+/*  Copyright (C) 1992-1998 by Dianne Skoll                    */
 /*  Copyright (C) 1999-2000 by Roaring Penguin Software Inc.   */
 /*                                                             */
 /***************************************************************/
@@ -447,16 +447,19 @@ static int ParseTimeTrig(ParsePtr s, TimeTrig *tim, int save_in_globals)
 	switch(tok.type) {
 	case T_Time:
 	    DBufFree(&buf);
+	    if (tim->ttime != NO_TIME) return E_TIME_TWICE;
 	    tim->ttime = tok.val;
 	    break;
 
 	case T_Delta:
 	    DBufFree(&buf);
+	    if (tim->delta != NO_DELTA) return E_DELTA_TWICE;
 	    tim->delta = (tok.val > 0) ? tok.val : -tok.val;
 	    break;
 
 	case T_Rep:
 	    DBufFree(&buf);
+	    if (tim->rep != NO_REP) return E_REP_TWICE;
 	    tim->rep = tok.val;
 	    break;
 
@@ -751,10 +754,10 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int jul)
 	DBufFree(&buf);
     }
 
-/* If it's NextMode, process as a CAL-type entry, and issue simple-calendar
-   format. */
+/* If it's NextMode, process as a ADVANCE_MODE-type entry, and issue
+   simple-calendar format. */
     if (NextMode) {
-	if ( (r=DoSubst(p, &buf, t, tim, jul, CAL_MODE)) ) return r;
+	if ( (r=DoSubst(p, &buf, t, tim, jul, ADVANCE_MODE)) ) return r;
 	if (!DBufLen(&buf)) {
 	    DBufFree(&buf);
 	    DBufFree(&pre_buf);
