@@ -5,7 +5,7 @@
 /*  Error definitions.                                         */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-1998 by David F. Skoll                  */
+/*  Copyright (C) 1992-1998 by Dianne Skoll                    */
 /*  Copyright (C) 1999-2000 by Roaring Penguin Software Inc.   */
 /*                                                             */
 /***************************************************************/
@@ -119,7 +119,7 @@
 #define E_CANT_CONVERT_TZ    99
 #define E_NO_MATCHING_REMS  100
 #define E_STRING_TOO_LONG   101
-
+#define E_TIME_TWICE        102
 #ifdef MK_GLOBALS
 #undef EXTERN
 #define EXTERN
@@ -234,7 +234,8 @@ EXTERN char *ErrMsg[]
     "Bad function in WARN clause",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 }
 #endif /* MK_GLOBALS */
 ;
