@@ -11,7 +11,7 @@
 /*                                                             */
 /*  This file is part of REMIND.                               */
 /*  This file is Copyright (C) 1993-1998 by Mikko Silvonen.    */
-/*  REMIND is Copyright (C) 1992-1998 by David F. Skoll        */
+/*  REMIND is Copyright (C) 1992-1998 by Dianne Skoll          */
 /*  Copyright 1999-2000 by Roaring Penguin Software Inc.       */
 /*                                                             */
 /***************************************************************/
@@ -302,7 +302,8 @@ EXTERN char *ErrMsg[] =
     "Virheellinen funktio WARN-lausekkeessa",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 
 #elif IBMEXTENDED
     "Ok",
@@ -406,7 +407,8 @@ EXTERN char *ErrMsg[] =
     "Virheellinen funktio WARN-lausekkeessa",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 
 #else
     "Ok",
@@ -510,7 +512,8 @@ EXTERN char *ErrMsg[] =
     "Virheellinen funktio WARN-lausekkeessa",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 
 
 #endif
@@ -522,7 +525,7 @@ EXTERN char *ErrMsg[] =
 #define L_USAGE_OVERRIDE 1
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 Dianne Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "Copyright 1999-2000 Roaring Penguin Software Inc.\n");
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETAVERSIO <<<<\n");
