@@ -8,10 +8,10 @@
 /*                                                             */
 /*  This file is part of REMIND.                               */
 /*                                                             */
-/*  REMIND is Copyright (C) 1992-1998 by David F. Skoll        */
+/*  REMIND is Copyright (C) 1992-1998 by Dianne Skoll          */
 /*  Copyright 1999-2000 by Roaring Penguin Software Inc.       */
 /*  This file is Copyright (C) 1993 by Laurent Duperval and    */
-/*  David F. Skoll.                                            */
+/*  Dianne Skoll.                                              */
 /*                                                             */
 /***************************************************************/
 
@@ -242,7 +242,8 @@ EXTERN char *ErrMsg[] =
     "Fonction ill\351gale apr\350s WARN",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 
 #else /* ISOLATIN1 */
     "Ok",
@@ -346,7 +347,8 @@ EXTERN char *ErrMsg[] =
     "Fonction illegale apres WARN",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 #endif /* ISOLATIN1 */
 };
 #endif /* MK_GLOBALS */
@@ -356,7 +358,7 @@ EXTERN char *ErrMsg[] =
 #define L_USAGE_OVERRIDE 1
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 Dianne Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "Copyright 1999-2000 Roaring Penguin Software Inc.\n");
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
