@@ -9,7 +9,7 @@
 /*  Polish.                                                    */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-1998 by David F. Skoll                  */
+/*  Copyright (C) 1992-1998 by Dianne Skoll                    */
 /*  Copyright 1999-2000 by Roaring Penguin Software Inc.       */
 /*                                                             */
 /***************************************************************/
@@ -281,7 +281,8 @@ EXTERN char *ErrMsg[] =
     "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 #else /* ISOLATIN1 */
     "OK",
     "Brakujacy ']'",
@@ -384,7 +385,8 @@ EXTERN char *ErrMsg[] =
     "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 #endif /* ISOLATIN1 */
 };
 #endif /* MK_GLOBALS */
@@ -394,7 +396,7 @@ EXTERN char *ErrMsg[] =
 #define L_USAGE_OVERRIDE 1
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 Dianne Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "Copyright 1999-2000 Roaring Penguin Software Inc.\n");
 #ifdef BETA
     fprintf(ErrFp, ">>>> BETA VERSION <<<<\n");
