@@ -8,10 +8,10 @@
 /*                                                             */
 /*  This file is part of REMIND.                               */
 /*                                                             */
-/*  REMIND is Copyright (C) 1992-1998 by David F. Skoll        */
+/*  REMIND is Copyright (C) 1992-1998 by Dianne Skoll          */
 /*  Copyright 1999-2000 by Roaring Penguin Software Inc.       */
 /*  This file is Copyright (C) 1996 by Marco Paganini and      */
-/*  David F. Skoll.                                            */
+/*  Dianne Skoll.                                              */
 /*                                                             */
 /***************************************************************/
 
@@ -247,7 +247,8 @@ EXTERN char *ErrMsg[] =
     "Funcao ilegal na clausula WARN",
     "Can't convert between time zones",
     "No files matching *.rem",
-    "String too long"
+    "String too long",
+    "Time specified twice"
 };
 #endif /* MK_GLOBALS */
 
@@ -256,7 +257,7 @@ EXTERN char *ErrMsg[] =
 #define L_USAGE_OVERRIDE 1
 void Usage(void)
 {
-    fprintf(ErrFp, "\nREMIND %s (versao %s) (C) 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
+    fprintf(ErrFp, "\nREMIND %s (versao %s) (C) 1992-1998 Dianne Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "(C) 1999-2000 Roaring Penguin Software Inc.\n");
 #ifdef BETA
     fprintf(ErrFp, ">>>> VERSAO BETA <<<<\n");
